# data_api

DataApi - JavaScript client for data_api
Cognitive Credit Company Data API
This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.JavascriptClientCodegen

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

To publish the library as a [npm](https://www.npmjs.com/), please follow the procedure in ["Publishing npm packages"](https://docs.npmjs.com/getting-started/publishing-npm-packages).

Then install it via:

```shell
npm install data_api --save
```

Finally, you need to build the module:

```shell
npm run build
```

##### Local development

To use the library locally without publishing to a remote npm registry, first install the dependencies by changing into the directory containing `package.json` (and this README). Let's call this `JAVASCRIPT_CLIENT_DIR`. Then run:

```shell
npm install
```

Next, [link](https://docs.npmjs.com/cli/link) it globally in npm with the following, also from `JAVASCRIPT_CLIENT_DIR`:

```shell
npm link
```

To use the link you just defined in your project, switch to the directory you want to use your data_api from, and run:

```shell
npm link /path/to/<JAVASCRIPT_CLIENT_DIR>
```

Finally, you need to build the module:

```shell
npm run build
```

#### git

If the library is hosted at a git repository, e.g.https://github.com/GIT_USER_ID/GIT_REPO_ID
then install it via:

```shell
    npm install GIT_USER_ID/GIT_REPO_ID --save
```

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`,
perform the following (assuming *main.js* is your entry file):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

### Webpack Configuration

Using Webpack you may encounter the following error: "Module not found: Error:
Cannot resolve module", most certainly you should disable AMD loader. Add/merge
the following section to your webpack config:

```javascript
module: {
  rules: [
    {
      parser: {
        amd: false
      }
    }
  ]
}
```

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var DataApi = require('data_api');

var defaultClient = DataApi.ApiClient.instance;
// Configure API key authorization: authorizeClient
var authorizeClient = defaultClient.authentications['authorizeClient'];
authorizeClient.apiKey = "YOUR API KEY"
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//authorizeClient.apiKeyPrefix['x-api-key'] = "Token"

var api = new DataApi.DefaultApi()
var interval = "interval_example"; // {String} identifier for the interval of comparables data to fetch
var opts = {
  'atTimestamp': new Date("2013-10-20T19:20:30+01:00"), // {Date} ISO-8601 Timestamp to return comparables snapshot for
  'companyIds': "companyIds_example", // {String} filter by supplied company ids
  'limit': 56, // {Number} maximum number of results to return - typically used when paging
  'continuationToken': "continuationToken_example", // {String} identifier of last result in previous result set - allows continuation of paged results
  'acceptEncoding': "'gzip, deflate, br'" // {String} client supported encodings (gzip, deflate, br)
};
var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
api.apiConsumerProjectLocalGetCompanyComparablesSubtypes(interval, opts, callback);

```

## Documentation for API Endpoints

All URIs are relative to *https://cognitivecreditapi.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DataApi.DefaultApi* | [**apiConsumerProjectLocalGetCompanyComparablesSubtypes**](docs/DefaultApi.md#apiConsumerProjectLocalGetCompanyComparablesSubtypes) | **GET** /comparables/{interval} | Get company comparables
*DataApi.DefaultApi* | [**apiConsumerProjectLocalGetCompanyDatapoint**](docs/DefaultApi.md#apiConsumerProjectLocalGetCompanyDatapoint) | **GET** /datapoints/{datapointId} | Get a company datapoint
*DataApi.DefaultApi* | [**apiConsumerProjectLocalGetCompanyFinancials**](docs/DefaultApi.md#apiConsumerProjectLocalGetCompanyFinancials) | **GET** /companies/{companyId}/financials | Get company financials
*DataApi.DefaultApi* | [**apiConsumerProjectLocalGetCompanyListings**](docs/DefaultApi.md#apiConsumerProjectLocalGetCompanyListings) | **GET** /companies | Get company descriptions
*DataApi.DefaultApi* | [**apiConsumerProjectLocalGetCompanyTimeSeries**](docs/DefaultApi.md#apiConsumerProjectLocalGetCompanyTimeSeries) | **GET** /companies/{companyId}/timeseries/{tag}/{interval} | Get company time series
*DataApi.DefaultApi* | [**apiConsumerProjectLocalGetComparablesUpdatesSince**](docs/DefaultApi.md#apiConsumerProjectLocalGetComparablesUpdatesSince) | **GET** /comparables/updates | Get company comparables updates for a given time period
*DataApi.DefaultApi* | [**apiConsumerProjectLocalGetPeriodDates**](docs/DefaultApi.md#apiConsumerProjectLocalGetPeriodDates) | **GET** /companies/{companyId}/periods | Get company period dates


## Documentation for Models

 - [DataApi.CommentRefsInner](docs/CommentRefsInner.md)
 - [DataApi.CompanyDatapointResponse](docs/CompanyDatapointResponse.md)
 - [DataApi.CompanyDatapointResponseData](docs/CompanyDatapointResponseData.md)
 - [DataApi.CompanyDescriptionResponse](docs/CompanyDescriptionResponse.md)
 - [DataApi.CompanyDescriptionResponseMeta](docs/CompanyDescriptionResponseMeta.md)
 - [DataApi.CompanyFinancialsResponse](docs/CompanyFinancialsResponse.md)
 - [DataApi.CompanyFinancialsResponseData](docs/CompanyFinancialsResponseData.md)
 - [DataApi.CompanyPeriodDatesResponse](docs/CompanyPeriodDatesResponse.md)
 - [DataApi.CompanyPeriodDatesResponseData](docs/CompanyPeriodDatesResponseData.md)
 - [DataApi.CompanyTimeSeriesResponse](docs/CompanyTimeSeriesResponse.md)
 - [DataApi.CompanyTimeSeriesResponseData](docs/CompanyTimeSeriesResponseData.md)
 - [DataApi.ComparablesInner](docs/ComparablesInner.md)
 - [DataApi.ComparablesResponse](docs/ComparablesResponse.md)
 - [DataApi.DataInner](docs/DataInner.md)
 - [DataApi.DataInner1](docs/DataInner1.md)
 - [DataApi.DataInner2](docs/DataInner2.md)
 - [DataApi.FinancialsInner](docs/FinancialsInner.md)
 - [DataApi.Multiplier](docs/Multiplier.md)
 - [DataApi.PartsInner](docs/PartsInner.md)
 - [DataApi.PeriodDatesInner](docs/PeriodDatesInner.md)
 - [DataApi.TimeSeriesInner](docs/TimeSeriesInner.md)


## Documentation for Authorization


Authentication schemes defined for the API:
### authorizeClient


- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

