# DataApi.DefaultApi

All URIs are relative to *https://cognitivecreditapi.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiConsumerProjectLocalGetCompanyComparablesSubtypes**](DefaultApi.md#apiConsumerProjectLocalGetCompanyComparablesSubtypes) | **GET** /comparables/{interval} | Get company comparables
[**apiConsumerProjectLocalGetCompanyDatapoint**](DefaultApi.md#apiConsumerProjectLocalGetCompanyDatapoint) | **GET** /datapoints/{datapointId} | Get a company datapoint
[**apiConsumerProjectLocalGetCompanyFinancials**](DefaultApi.md#apiConsumerProjectLocalGetCompanyFinancials) | **GET** /companies/{companyId}/financials | Get company financials
[**apiConsumerProjectLocalGetCompanyListings**](DefaultApi.md#apiConsumerProjectLocalGetCompanyListings) | **GET** /companies | Get company descriptions
[**apiConsumerProjectLocalGetCompanyTimeSeries**](DefaultApi.md#apiConsumerProjectLocalGetCompanyTimeSeries) | **GET** /companies/{companyId}/timeseries/{tag}/{interval} | Get company time series
[**apiConsumerProjectLocalGetComparablesUpdatesSince**](DefaultApi.md#apiConsumerProjectLocalGetComparablesUpdatesSince) | **GET** /comparables/updates | Get company comparables updates for a given time period
[**apiConsumerProjectLocalGetPeriodDates**](DefaultApi.md#apiConsumerProjectLocalGetPeriodDates) | **GET** /companies/{companyId}/periods | Get company period dates



## apiConsumerProjectLocalGetCompanyComparablesSubtypes

> ComparablesResponse apiConsumerProjectLocalGetCompanyComparablesSubtypes(interval, opts)

Get company comparables

Returns comparables data for a list of companies for the allowed coverage_universe

### Example

```javascript
import DataApi from 'data_api';
let defaultClient = DataApi.ApiClient.instance;
// Configure API key authorization: authorizeClient
let authorizeClient = defaultClient.authentications['authorizeClient'];
authorizeClient.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//authorizeClient.apiKeyPrefix = 'Token';

let apiInstance = new DataApi.DefaultApi();
let interval = "interval_example"; // String | identifier for the interval of comparables data to fetch
let opts = {
  'atTimestamp': new Date("2013-10-20T19:20:30+01:00"), // Date | ISO-8601 Timestamp to return comparables snapshot for
  'companyIds': "companyIds_example", // String | filter by supplied company ids
  'limit': 56, // Number | maximum number of results to return - typically used when paging
  'continuationToken': "continuationToken_example", // String | identifier of last result in previous result set - allows continuation of paged results
  'acceptEncoding': "'gzip, deflate, br'" // String | client supported encodings (gzip, deflate, br)
};
apiInstance.apiConsumerProjectLocalGetCompanyComparablesSubtypes(interval, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **interval** | **String**| identifier for the interval of comparables data to fetch | 
 **atTimestamp** | **Date**| ISO-8601 Timestamp to return comparables snapshot for | [optional] 
 **companyIds** | **String**| filter by supplied company ids | [optional] 
 **limit** | **Number**| maximum number of results to return - typically used when paging | [optional] 
 **continuationToken** | **String**| identifier of last result in previous result set - allows continuation of paged results | [optional] 
 **acceptEncoding** | **String**| client supported encodings (gzip, deflate, br) | [optional] [default to &#39;gzip, deflate, br&#39;]

### Return type

[**ComparablesResponse**](ComparablesResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## apiConsumerProjectLocalGetCompanyDatapoint

> CompanyDatapointResponse apiConsumerProjectLocalGetCompanyDatapoint(datapointId, opts)

Get a company datapoint

Returns details of an individual datapoint for a company

### Example

```javascript
import DataApi from 'data_api';
let defaultClient = DataApi.ApiClient.instance;
// Configure API key authorization: authorizeClient
let authorizeClient = defaultClient.authentications['authorizeClient'];
authorizeClient.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//authorizeClient.apiKeyPrefix = 'Token';

let apiInstance = new DataApi.DefaultApi();
let datapointId = "datapointId_example"; // String | identifier for the datapoint
let opts = {
  'acceptEncoding': "'gzip, deflate, br'" // String | client supported encodings (gzip, deflate, br)
};
apiInstance.apiConsumerProjectLocalGetCompanyDatapoint(datapointId, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **datapointId** | **String**| identifier for the datapoint | 
 **acceptEncoding** | **String**| client supported encodings (gzip, deflate, br) | [optional] [default to &#39;gzip, deflate, br&#39;]

### Return type

[**CompanyDatapointResponse**](CompanyDatapointResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## apiConsumerProjectLocalGetCompanyFinancials

> CompanyFinancialsResponse apiConsumerProjectLocalGetCompanyFinancials(companyId, opts)

Get company financials

Returns historical financials data for single company

### Example

```javascript
import DataApi from 'data_api';
let defaultClient = DataApi.ApiClient.instance;
// Configure API key authorization: authorizeClient
let authorizeClient = defaultClient.authentications['authorizeClient'];
authorizeClient.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//authorizeClient.apiKeyPrefix = 'Token';

let apiInstance = new DataApi.DefaultApi();
let companyId = "companyId_example"; // String | identifier for the company to fetch financials for
let opts = {
  'atTimestamp': new Date("2013-10-20T19:20:30+01:00"), // Date | ISO-8601 Timestamp to return financials snapshot for
  'acceptEncoding': "'gzip, deflate, br'" // String | client supported encodings (gzip, deflate, br)
};
apiInstance.apiConsumerProjectLocalGetCompanyFinancials(companyId, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyId** | **String**| identifier for the company to fetch financials for | 
 **atTimestamp** | **Date**| ISO-8601 Timestamp to return financials snapshot for | [optional] 
 **acceptEncoding** | **String**| client supported encodings (gzip, deflate, br) | [optional] [default to &#39;gzip, deflate, br&#39;]

### Return type

[**CompanyFinancialsResponse**](CompanyFinancialsResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## apiConsumerProjectLocalGetCompanyListings

> CompanyDescriptionResponse apiConsumerProjectLocalGetCompanyListings(opts)

Get company descriptions

Returns a list of company description objects.

### Example

```javascript
import DataApi from 'data_api';
let defaultClient = DataApi.ApiClient.instance;
// Configure API key authorization: authorizeClient
let authorizeClient = defaultClient.authentications['authorizeClient'];
authorizeClient.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//authorizeClient.apiKeyPrefix = 'Token';

let apiInstance = new DataApi.DefaultApi();
let opts = {
  'atTimestamp': new Date("2013-10-20T19:20:30+01:00"), // Date | ISO-8601 Timestamp to return companies snapshot for
  'isRetired': "isRetired_example", // String | filter by 'retired' status - (true|false)
  'companyIds': "companyIds_example", // String | filter by supplied company ids - comma separated list
  'tickers': "tickers_example", // String | filter by supplied company tickers
  'limit': 56, // Number | maximum number of results to return - typically used when paging
  'updatedAfter': new Date("2013-10-20T19:20:30+01:00"), // Date | Only return company descriptions added or updated on or after this ISO-8601 timestamp
  'updatedBefore': new Date("2013-10-20T19:20:30+01:00"), // Date | Only return company descriptions added or updated before this ISO-8601 timestamp
  'lastReportedDateAfter': new Date("2013-10-20T19:20:30+01:00"), // Date | Only return company descriptions for companies with reports on or after this ISO-8601 timestamp
  'lastReportedDateBefore': new Date("2013-10-20T19:20:30+01:00"), // Date | Only return company descriptions for companies with reports before this ISO-8601 timestamp
  'continuationToken': "continuationToken_example", // String | identifier of last result in previous result set - allows continuation of paged results
  'acceptEncoding': "'gzip, deflate, br'" // String | client supported encodings (gzip, deflate, br)
};
apiInstance.apiConsumerProjectLocalGetCompanyListings(opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **atTimestamp** | **Date**| ISO-8601 Timestamp to return companies snapshot for | [optional] 
 **isRetired** | **String**| filter by &#39;retired&#39; status - (true|false) | [optional] 
 **companyIds** | **String**| filter by supplied company ids - comma separated list | [optional] 
 **tickers** | **String**| filter by supplied company tickers | [optional] 
 **limit** | **Number**| maximum number of results to return - typically used when paging | [optional] 
 **updatedAfter** | **Date**| Only return company descriptions added or updated on or after this ISO-8601 timestamp | [optional] 
 **updatedBefore** | **Date**| Only return company descriptions added or updated before this ISO-8601 timestamp | [optional] 
 **lastReportedDateAfter** | **Date**| Only return company descriptions for companies with reports on or after this ISO-8601 timestamp | [optional] 
 **lastReportedDateBefore** | **Date**| Only return company descriptions for companies with reports before this ISO-8601 timestamp | [optional] 
 **continuationToken** | **String**| identifier of last result in previous result set - allows continuation of paged results | [optional] 
 **acceptEncoding** | **String**| client supported encodings (gzip, deflate, br) | [optional] [default to &#39;gzip, deflate, br&#39;]

### Return type

[**CompanyDescriptionResponse**](CompanyDescriptionResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## apiConsumerProjectLocalGetCompanyTimeSeries

> CompanyTimeSeriesResponse apiConsumerProjectLocalGetCompanyTimeSeries(companyId, tag, interval, opts)

Get company time series

Returns all historical values of a specific comparable for a given company and interval

### Example

```javascript
import DataApi from 'data_api';
let defaultClient = DataApi.ApiClient.instance;
// Configure API key authorization: authorizeClient
let authorizeClient = defaultClient.authentications['authorizeClient'];
authorizeClient.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//authorizeClient.apiKeyPrefix = 'Token';

let apiInstance = new DataApi.DefaultApi();
let companyId = "companyId_example"; // String | identifier for the company to fetch time series data for
let tag = "tag_example"; // String | identifier for the comparable tag to fetch time series data for
let interval = "interval_example"; // String | identifier for the interval to fetch time series data for
let opts = {
  'acceptEncoding': "'gzip, deflate, br'" // String | client supported encodings (gzip, deflate, br)
};
apiInstance.apiConsumerProjectLocalGetCompanyTimeSeries(companyId, tag, interval, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyId** | **String**| identifier for the company to fetch time series data for | 
 **tag** | **String**| identifier for the comparable tag to fetch time series data for | 
 **interval** | **String**| identifier for the interval to fetch time series data for | 
 **acceptEncoding** | **String**| client supported encodings (gzip, deflate, br) | [optional] [default to &#39;gzip, deflate, br&#39;]

### Return type

[**CompanyTimeSeriesResponse**](CompanyTimeSeriesResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## apiConsumerProjectLocalGetComparablesUpdatesSince

> ComparablesResponse apiConsumerProjectLocalGetComparablesUpdatesSince(opts)

Get company comparables updates for a given time period

Returns comparables data for a list of companies for the allowed coverage_universe, from a given start timestamp and optional end timestamp

### Example

```javascript
import DataApi from 'data_api';
let defaultClient = DataApi.ApiClient.instance;
// Configure API key authorization: authorizeClient
let authorizeClient = defaultClient.authentications['authorizeClient'];
authorizeClient.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//authorizeClient.apiKeyPrefix = 'Token';

let apiInstance = new DataApi.DefaultApi();
let opts = {
  'startTimestamp': new Date("2013-10-20T19:20:30+01:00"), // Date | ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp)
  'endTimestamp': new Date("2013-10-20T19:20:30+01:00"), // Date | ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp)
  'companyIds': "companyIds_example", // String | filter by supplied company ids
  'limit': 56, // Number | maximum number of results to return - typically used when paging
  'continuationToken': "continuationToken_example", // String | identifier of last result in previous result set - allows continuation of paged results
  'acceptEncoding': "'gzip, deflate, br'" // String | client supported encodings (gzip, deflate, br)
};
apiInstance.apiConsumerProjectLocalGetComparablesUpdatesSince(opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **startTimestamp** | **Date**| ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp) | [optional] 
 **endTimestamp** | **Date**| ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp) | [optional] 
 **companyIds** | **String**| filter by supplied company ids | [optional] 
 **limit** | **Number**| maximum number of results to return - typically used when paging | [optional] 
 **continuationToken** | **String**| identifier of last result in previous result set - allows continuation of paged results | [optional] 
 **acceptEncoding** | **String**| client supported encodings (gzip, deflate, br) | [optional] [default to &#39;gzip, deflate, br&#39;]

### Return type

[**ComparablesResponse**](ComparablesResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## apiConsumerProjectLocalGetPeriodDates

> CompanyPeriodDatesResponse apiConsumerProjectLocalGetPeriodDates(companyId, opts)

Get company period dates

Returns end dates of financial reporting periods for given company

### Example

```javascript
import DataApi from 'data_api';
let defaultClient = DataApi.ApiClient.instance;
// Configure API key authorization: authorizeClient
let authorizeClient = defaultClient.authentications['authorizeClient'];
authorizeClient.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//authorizeClient.apiKeyPrefix = 'Token';

let apiInstance = new DataApi.DefaultApi();
let companyId = "companyId_example"; // String | identifier for the company to fetch financials for
let opts = {
  'acceptEncoding': "'gzip, deflate, br'" // String | client supported encodings (gzip, deflate, br)
};
apiInstance.apiConsumerProjectLocalGetPeriodDates(companyId, opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyId** | **String**| identifier for the company to fetch financials for | 
 **acceptEncoding** | **String**| client supported encodings (gzip, deflate, br) | [optional] [default to &#39;gzip, deflate, br&#39;]

### Return type

[**CompanyPeriodDatesResponse**](CompanyPeriodDatesResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

